# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementType = typing.Union[
    typing.Literal["built_area", "gross_weight", "land_area", "net_weight", "quantity"], typing.Any
]
