# This file was auto-generated by Fern from our API Definition.

import typing
from ...generated_types.types.attributes import Attributes
from ...generated_types.types.relationships import Relationships

OntologyEntityTypeField = typing.Union[Attributes, Relationships]
