# This file was auto-generated by Fern from our API Definition.

import typing

AddressType = typing.Union[
    typing.Literal[
        "arrival",
        "business",
        "departure",
        "mailing",
        "operations",
        "physical",
        "place_of_birth",
        "receiver_address",
        "registered",
        "shipper_address",
        "transit",
    ],
    typing.Any,
]
