# This file was auto-generated by Fern from our API Definition.

import typing

Risk = typing.Union[
    typing.Literal[
        "aspi_uyghur_forced_labor_report_entity",
        "aspi_uyghur_forced_labor_report_entity_adjacent",
        "basel_aml",
        "bis_addresses_high_diversion_risk",
        "bis_boycott_requester_list",
        "chinese_soe_adjacent",
        "chinese_state_owned",
        "cmic_entity",
        "cmic_entity_50_percent_rule",
        "controlled_by_aus_sanctioned",
        "controlled_by_eu_sanctioned",
        "controlled_by_jpn_sanctioned",
        "controlled_by_ofac_fto_sanctioned",
        "controlled_by_ofac_illicit_drugs_eo14059_sanctioned",
        "controlled_by_ofac_sdgt_sanctioned",
        "controlled_by_ofac_sdn",
        "controlled_by_ofac_sdnt_sanctioned",
        "controlled_by_ofac_sdntk_sanctioned",
        "controlled_by_uk_sanctioned",
        "controlled_by_ukr_sanctioned",
        "controlled_by_un_sanctioned",
        "cpi_score",
        "entity_licensed_with_fsb_rf",
        "esg_score_high",
        "esg_score_medium",
        "esg_score_very_high",
        "eu_50_percent_rule",
        "eu_high_risk_third",
        "eu_minority_ownership",
        "eu_sanctioned",
        "export_controls",
        "export_controls_adjacent",
        "export_controls_bis_entity",
        "export_controls_bis_entity_50_percent_rule",
        "export_controls_bis_meu",
        "export_controls_bis_meu_50_percent_rule",
        "export_controls_section_1260h",
        "export_controls_section_1260h_50_percent_rule",
        "export_controls_unverified_list",
        "export_controls_unverified_list_50_percent_rule",
        "export_to_chinese_soe",
        "export_to_sanctioned",
        "export_to_soe",
        "exports_bis_high_priority_items_critical_components_direct",
        "exports_bis_high_priority_items_critical_components_indirect",
        "exports_bis_high_priority_items_direct",
        "exports_bis_high_priority_items_indirect",
        "exports_conflict_minerals",
        "exports_eudr_shipment_cattle",
        "exports_eudr_shipment_cocoa",
        "exports_eudr_shipment_coffee",
        "exports_eudr_shipment_palm_oil",
        "exports_eudr_shipment_rubber",
        "exports_eudr_shipment_soya",
        "exports_eudr_shipment_wood",
        "exports_ilab_child_labor",
        "exports_ilab_forced_labor",
        "exports_russian_coal",
        "exports_russian_gold",
        "exports_russian_important_good",
        "exports_russian_oil",
        "exports_to_bis_addresses_high_diversion_risk",
        "exports_to_entity_licensed_with_fsb_rf",
        "exports_to_jpn_meti_end_user_entity",
        "exports_to_jpn_mofa_export_ban_entity",
        "exports_to_sanctioned_arg_repet_jus_entity",
        "exports_to_sanctioned_aus_dfat_entity",
        "exports_to_sanctioned_bel_fpsf_entity",
        "exports_to_sanctioned_can_gac_entity",
        "exports_to_sanctioned_che_seco_entity",
        "exports_to_sanctioned_cze_mof_entity",
        "exports_to_sanctioned_eu_dg_fisma_ec_entity",
        "exports_to_sanctioned_eu_ec_regulation_833_2014_entity",
        "exports_to_sanctioned_eu_ec_sanctions_map_entity",
        "exports_to_sanctioned_eu_sanctions_entity",
        "exports_to_sanctioned_fra_dgt_mefids_entity",
        "exports_to_sanctioned_gbr_fcdo_entity",
        "exports_to_sanctioned_gbr_hmt_ofsi_entity",
        "exports_to_sanctioned_isr_mod_nbctf_entity",
        "exports_to_sanctioned_jpn_mof_entity",
        "exports_to_sanctioned_ltu_mi_entity",
        "exports_to_sanctioned_lva_fis_entity",
        "exports_to_sanctioned_mys_moha_entity",
        "exports_to_sanctioned_nld_mofa_entity",
        "exports_to_sanctioned_nzl_mfat_rus_entity",
        "exports_to_sanctioned_pol_mia_entity",
        "exports_to_sanctioned_sgp_agc_entity",
        "exports_to_sanctioned_ukr_nsdc_entity",
        "exports_to_sanctioned_ukr_sfms_entity",
        "exports_to_sanctioned_un_sc_entity",
        "exports_to_sanctioned_usa_ofac_non_sdn_entity",
        "exports_to_sanctioned_usa_ofac_sdn_entity",
        "exports_to_sanctioned_xxx_ebrd_entity",
        "exports_to_sanctioned_xxx_iabd_entity",
        "exports_to_usa_aeca_debarred_entity",
        "exports_to_usa_bis_denied_persons_entity",
        "exports_to_usa_bis_entity",
        "exports_to_usa_bis_meu_entity",
        "exports_to_usa_bis_unverified_entity",
        "exports_to_usa_isn_entity",
        "exports_to_usa_section_1260h_entity",
        "forced_labor_aspi_origin_direct",
        "forced_labor_aspi_origin_subtier",
        "forced_labor_aspi_origin_subtier_product_blueprint",
        "forced_labor_china_keywords",
        "forced_labor_sheffield_hallam_university_reports_origin_direct",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier_product_blueprint",
        "forced_labor_uflpa_origin_direct",
        "forced_labor_uflpa_origin_subtier",
        "forced_labor_uflpa_origin_subtier_product_blueprint",
        "forced_labor_wro_origin_direct",
        "forced_labor_wro_origin_subtier",
        "forced_labor_wro_origin_subtier_product_blueprint",
        "forced_labor_xinjiang_contractors",
        "forced_labor_xinjiang_cotton_entity",
        "forced_labor_xinjiang_geospatial",
        "forced_labor_xinjiang_name",
        "forced_labor_xinjiang_operations",
        "forced_labor_xinjiang_origin_direct",
        "forced_labor_xinjiang_origin_subtier",
        "forced_labor_xinjiang_origin_subtier_product_blueprint",
        "forced_labor_xinjiang_registration",
        "forced_labor_xinjiang_uflpa",
        "forced_labor_xinjiang_uflpa_adjacent",
        "former_soe",
        "former_wro_entity",
        "formerly_sanctioned",
        "formerly_sanctioned_arg_repet_jus",
        "formerly_sanctioned_aus_dfat",
        "formerly_sanctioned_bel_fpsf",
        "formerly_sanctioned_can_gac",
        "formerly_sanctioned_che_seco",
        "formerly_sanctioned_cze_mof",
        "formerly_sanctioned_eu_dg_fisma_ec",
        "formerly_sanctioned_eu_ec_regulation_833_2014",
        "formerly_sanctioned_eu_ec_sanctions_map",
        "formerly_sanctioned_eu_sanctions",
        "formerly_sanctioned_fra_dgt_mefids",
        "formerly_sanctioned_gbr_fcdo",
        "formerly_sanctioned_gbr_hmt_ofsi",
        "formerly_sanctioned_isr_mod_nbctf",
        "formerly_sanctioned_jpn_mof",
        "formerly_sanctioned_ltu_mi",
        "formerly_sanctioned_lva_fis",
        "formerly_sanctioned_mys_moha",
        "formerly_sanctioned_nld_mofa",
        "formerly_sanctioned_nzl_mfat_rus",
        "formerly_sanctioned_pol_mia",
        "formerly_sanctioned_sgp_agc",
        "formerly_sanctioned_ukr_nsdc",
        "formerly_sanctioned_ukr_sfms",
        "formerly_sanctioned_un_sc",
        "formerly_sanctioned_usa_ofac_non_sdn",
        "formerly_sanctioned_usa_ofac_sdn",
        "formerly_sanctioned_xxx_ebrd",
        "formerly_sanctioned_xxx_iabd",
        "imports_bis_high_priority_items",
        "imports_bis_high_priority_items_critical_components",
        "imports_conflict_minerals",
        "imports_eudr_shipment_cattle",
        "imports_eudr_shipment_cocoa",
        "imports_eudr_shipment_coffee",
        "imports_eudr_shipment_palm_oil",
        "imports_eudr_shipment_rubber",
        "imports_eudr_shipment_soya",
        "imports_eudr_shipment_wood",
        "imports_from_bis_addresses_high_diversion_risk",
        "imports_ilab_child_labor",
        "imports_ilab_forced_labor",
        "imports_ndaa_889_telecom_equipment",
        "imports_russian_coal",
        "imports_russian_gold",
        "imports_russian_important_good",
        "imports_russian_oil",
        "jpn_meti_end_user",
        "jpn_mofa_export_ban",
        "law_enforcement_action",
        "meu_list_contractors",
        "military_civil_fusion",
        "military_civil_fusion_50_percent_rule",
        "military_end_use_china_keywords",
        "ndaa_889_covered_entities",
        "ofac_50_percent_rule",
        "ofac_fto_sanctioned",
        "ofac_illicit_drugs_eo14059_sanctioned",
        "ofac_minority_ownership",
        "ofac_sdgt_sanctioned",
        "ofac_sdn",
        "ofac_sdn_mex_dto_sanctioned",
        "ofac_sdn_mex_dto_sanctioned_adjacent",
        "ofac_sdnt_sanctioned",
        "ofac_sdntk_sanctioned",
        "owned_by_aspi_forced_labor_entity",
        "owned_by_bis_meu_entity",
        "owned_by_chinese_soe",
        "owned_by_cmic_entity",
        "owned_by_entity_in_export_controls",
        "owned_by_forced_labor_xinjiang_uflpa",
        "owned_by_jpn_meti_end_user_entity",
        "owned_by_jpn_mofa_export_ban_entity",
        "owned_by_military_civil_fusion",
        "owned_by_ofac_fto_sanctioned",
        "owned_by_ofac_illicit_drugs_eo14059_sanctioned",
        "owned_by_ofac_sdgt_sanctioned",
        "owned_by_ofac_sdn_mex_dto_sanctioned",
        "owned_by_ofac_sdnt_sanctioned",
        "owned_by_ofac_sdntk_sanctioned",
        "owned_by_sanctioned_arg_repet_jus_entity",
        "owned_by_sanctioned_aus_dfat_entity",
        "owned_by_sanctioned_bel_fpsf_entity",
        "owned_by_sanctioned_can_gac_entity",
        "owned_by_sanctioned_che_seco_entity",
        "owned_by_sanctioned_cze_mof_entity",
        "owned_by_sanctioned_entity",
        "owned_by_sanctioned_eu_dg_fisma_ec_entity",
        "owned_by_sanctioned_eu_ec_regulation_833_2014_entity",
        "owned_by_sanctioned_eu_ec_sanctions_map_entity",
        "owned_by_sanctioned_eu_sanctions_entity",
        "owned_by_sanctioned_fra_dgt_mefids_entity",
        "owned_by_sanctioned_gbr_fcdo_entity",
        "owned_by_sanctioned_gbr_hmt_ofsi_entity",
        "owned_by_sanctioned_isr_mod_nbctf_entity",
        "owned_by_sanctioned_jpn_mof_entity",
        "owned_by_sanctioned_ltu_mi_entity",
        "owned_by_sanctioned_lva_fis_entity",
        "owned_by_sanctioned_mys_moha_entity",
        "owned_by_sanctioned_nld_mofa_entity",
        "owned_by_sanctioned_nzl_mfat_rus_entity",
        "owned_by_sanctioned_pol_mia_entity",
        "owned_by_sanctioned_sgp_agc_entity",
        "owned_by_sanctioned_ukr_nsdc_entity",
        "owned_by_sanctioned_ukr_sfms_entity",
        "owned_by_sanctioned_un_sc_entity",
        "owned_by_sanctioned_usa_ofac_non_sdn_entity",
        "owned_by_sanctioned_usa_ofac_sdn_entity",
        "owned_by_sanctioned_xxx_ebrd_entity",
        "owned_by_sanctioned_xxx_iabd_entity",
        "owned_by_section_1260h_entity",
        "owned_by_sheffield_hallam_university_reports_forced_labor_entity",
        "owned_by_soe",
        "owned_by_usa_aeca_debarred_entity",
        "owned_by_usa_bis_denied_persons_entity",
        "owned_by_usa_bis_entity",
        "owned_by_usa_bis_meu_entity",
        "owned_by_usa_bis_unverified_entity",
        "owned_by_usa_isn_entity",
        "owned_by_usa_section_1260h_entity",
        "owned_by_wro_entity",
        "owned_by_xinjiang_entity",
        "owner_of_aspi_forced_labor_entity",
        "owner_of_chinese_soe",
        "owner_of_export_controls_entity",
        "owner_of_forced_labor_xinjiang_entity",
        "owner_of_forced_labor_xinjiang_uflpa",
        "owner_of_jpn_meti_end_user_entity",
        "owner_of_jpn_mofa_export_ban_entity",
        "owner_of_ofac_fto_sanctioned",
        "owner_of_ofac_illicit_drugs_eo14059_sanctioned",
        "owner_of_ofac_sdgt_sanctioned",
        "owner_of_ofac_sdn_mex_dto_sanctioned",
        "owner_of_ofac_sdnt_sanctioned",
        "owner_of_ofac_sdntk_sanctioned",
        "owner_of_regulatory_action_entity",
        "owner_of_sanctioned_arg_repet_jus_entity",
        "owner_of_sanctioned_aus_dfat_entity",
        "owner_of_sanctioned_bel_fpsf_entity",
        "owner_of_sanctioned_can_gac_entity",
        "owner_of_sanctioned_che_seco_entity",
        "owner_of_sanctioned_cze_mof_entity",
        "owner_of_sanctioned_entity",
        "owner_of_sanctioned_eu_dg_fisma_ec_entity",
        "owner_of_sanctioned_eu_ec_regulation_833_2014_entity",
        "owner_of_sanctioned_eu_ec_sanctions_map_entity",
        "owner_of_sanctioned_eu_sanctions_entity",
        "owner_of_sanctioned_fra_dgt_mefids_entity",
        "owner_of_sanctioned_gbr_fcdo_entity",
        "owner_of_sanctioned_gbr_hmt_ofsi_entity",
        "owner_of_sanctioned_isr_mod_nbctf_entity",
        "owner_of_sanctioned_jpn_mof_entity",
        "owner_of_sanctioned_ltu_mi_entity",
        "owner_of_sanctioned_lva_fis_entity",
        "owner_of_sanctioned_mys_moha_entity",
        "owner_of_sanctioned_nld_mofa_entity",
        "owner_of_sanctioned_nzl_mfat_rus_entity",
        "owner_of_sanctioned_pol_mia_entity",
        "owner_of_sanctioned_sgp_agc_entity",
        "owner_of_sanctioned_ukr_nsdc_entity",
        "owner_of_sanctioned_ukr_sfms_entity",
        "owner_of_sanctioned_un_sc_entity",
        "owner_of_sanctioned_usa_ofac_non_sdn_entity",
        "owner_of_sanctioned_usa_ofac_sdn_entity",
        "owner_of_sanctioned_xxx_ebrd_entity",
        "owner_of_sanctioned_xxx_iabd_entity",
        "owner_of_sheffield_hallam_university_reports_forced_labor_entity",
        "owner_of_soe",
        "owner_of_usa_aeca_debarred_entity",
        "owner_of_usa_bis_denied_persons_entity",
        "owner_of_usa_bis_entity",
        "owner_of_usa_bis_meu_entity",
        "owner_of_usa_bis_unverified_entity",
        "owner_of_usa_isn_entity",
        "owner_of_usa_section_1260h_entity",
        "owner_of_wro_entity",
        "pep",
        "pep_adjacent",
        "psa_bis_boycott_requester_list",
        "psa_chinese_state_owned",
        "psa_cmic_entity_50_percent_rule",
        "psa_entity_licensed_with_fsb_rf",
        "psa_eu_50_percent_rule",
        "psa_eu_minority_ownership",
        "psa_export_controls",
        "psa_export_controls_bis_entity_50_percent_rule",
        "psa_export_controls_bis_meu_50_percent_rule",
        "psa_export_controls_section_1260h_50_percent_rule",
        "psa_export_controls_unverified_list_50_percent_rule",
        "psa_export_to_chinese_soe",
        "psa_export_to_sanctioned",
        "psa_export_to_soe",
        "psa_exports_bis_high_priority_items_critical_components_direct",
        "psa_exports_bis_high_priority_items_critical_components_indirect",
        "psa_exports_bis_high_priority_items_direct",
        "psa_exports_bis_high_priority_items_indirect",
        "psa_exports_conflict_minerals",
        "psa_exports_eudr_shipment_cattle",
        "psa_exports_eudr_shipment_cocoa",
        "psa_exports_eudr_shipment_coffee",
        "psa_exports_eudr_shipment_palm_oil",
        "psa_exports_eudr_shipment_rubber",
        "psa_exports_eudr_shipment_soya",
        "psa_exports_eudr_shipment_wood",
        "psa_exports_ilab_child_labor",
        "psa_exports_ilab_forced_labor",
        "psa_exports_russian_coal",
        "psa_exports_russian_gold",
        "psa_exports_russian_important_good",
        "psa_exports_russian_oil",
        "psa_exports_to_bis_addresses_high_diversion_risk",
        "psa_exports_to_entity_licensed_with_fsb_rf",
        "psa_exports_to_jpn_meti_end_user_entity",
        "psa_exports_to_jpn_mofa_export_ban_entity",
        "psa_exports_to_sanctioned_arg_repet_jus_entity",
        "psa_exports_to_sanctioned_aus_dfat_entity",
        "psa_exports_to_sanctioned_bel_fpsf_entity",
        "psa_exports_to_sanctioned_can_gac_entity",
        "psa_exports_to_sanctioned_che_seco_entity",
        "psa_exports_to_sanctioned_cze_mof_entity",
        "psa_exports_to_sanctioned_eu_dg_fisma_ec_entity",
        "psa_exports_to_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_exports_to_sanctioned_eu_ec_sanctions_map_entity",
        "psa_exports_to_sanctioned_eu_sanctions_entity",
        "psa_exports_to_sanctioned_fra_dgt_mefids_entity",
        "psa_exports_to_sanctioned_gbr_fcdo_entity",
        "psa_exports_to_sanctioned_gbr_hmt_ofsi_entity",
        "psa_exports_to_sanctioned_isr_mod_nbctf_entity",
        "psa_exports_to_sanctioned_jpn_mof_entity",
        "psa_exports_to_sanctioned_ltu_mi_entity",
        "psa_exports_to_sanctioned_lva_fis_entity",
        "psa_exports_to_sanctioned_mys_moha_entity",
        "psa_exports_to_sanctioned_nld_mofa_entity",
        "psa_exports_to_sanctioned_nzl_mfat_rus_entity",
        "psa_exports_to_sanctioned_pol_mia_entity",
        "psa_exports_to_sanctioned_sgp_agc_entity",
        "psa_exports_to_sanctioned_ukr_nsdc_entity",
        "psa_exports_to_sanctioned_ukr_sfms_entity",
        "psa_exports_to_sanctioned_un_sc_entity",
        "psa_exports_to_sanctioned_usa_ofac_non_sdn_entity",
        "psa_exports_to_sanctioned_usa_ofac_sdn_entity",
        "psa_exports_to_sanctioned_xxx_ebrd_entity",
        "psa_exports_to_sanctioned_xxx_iabd_entity",
        "psa_exports_to_usa_aeca_debarred_entity",
        "psa_exports_to_usa_bis_denied_persons_entity",
        "psa_exports_to_usa_bis_entity",
        "psa_exports_to_usa_bis_meu_entity",
        "psa_exports_to_usa_bis_unverified_entity",
        "psa_exports_to_usa_isn_entity",
        "psa_exports_to_usa_section_1260h_entity",
        "psa_forced_labor_aspi_origin_direct",
        "psa_forced_labor_aspi_origin_subtier",
        "psa_forced_labor_aspi_uyghur",
        "psa_forced_labor_sheffield_hallam_university_reports_origin_direct",
        "psa_forced_labor_sheffield_hallam_university_reports_origin_subtier",
        "psa_forced_labor_uflpa_origin_direct",
        "psa_forced_labor_uflpa_origin_subtier",
        "psa_forced_labor_wro_origin_direct",
        "psa_forced_labor_wro_origin_subtier",
        "psa_forced_labor_xinjiang_cotton_entity",
        "psa_forced_labor_xinjiang_geospatial",
        "psa_forced_labor_xinjiang_name",
        "psa_forced_labor_xinjiang_operations",
        "psa_forced_labor_xinjiang_origin_direct",
        "psa_forced_labor_xinjiang_origin_subtier",
        "psa_forced_labor_xinjiang_registration",
        "psa_forced_labor_xinjiang_uflpa",
        "psa_imports_bis_high_priority_items",
        "psa_imports_bis_high_priority_items_critical_components",
        "psa_imports_conflict_minerals",
        "psa_imports_eudr_shipment_cattle",
        "psa_imports_eudr_shipment_cocoa",
        "psa_imports_eudr_shipment_coffee",
        "psa_imports_eudr_shipment_palm_oil",
        "psa_imports_eudr_shipment_rubber",
        "psa_imports_eudr_shipment_soya",
        "psa_imports_eudr_shipment_wood",
        "psa_imports_from_bis_addresses_high_diversion_risk",
        "psa_imports_ilab_child_labor",
        "psa_imports_ilab_forced_labor",
        "psa_imports_ndaa_889_telecom_equipment",
        "psa_imports_russian_coal",
        "psa_imports_russian_gold",
        "psa_imports_russian_important_good",
        "psa_imports_russian_oil",
        "psa_jpn_meti_end_user",
        "psa_jpn_mofa_export_ban",
        "psa_military_civil_fusion",
        "psa_military_civil_fusion_50_percent_rule",
        "psa_ofac_50_percent_rule",
        "psa_ofac_minority_ownership",
        "psa_ofac_sdn_mex_dto_sanctioned_adjacent",
        "psa_owned_by_aspi_forced_labor_entity",
        "psa_owned_by_bis_meu_entity",
        "psa_owned_by_chinese_soe",
        "psa_owned_by_cmic_entity",
        "psa_owned_by_entity_in_export_controls",
        "psa_owned_by_forced_labor_xinjiang_uflpa",
        "psa_owned_by_jpn_meti_end_user_entity",
        "psa_owned_by_jpn_mofa_export_ban_entity",
        "psa_owned_by_military_civil_fusion",
        "psa_owned_by_ofac_fto_sanctioned",
        "psa_owned_by_ofac_illicit_drugs_eo14059_sanctioned",
        "psa_owned_by_ofac_sdgt_sanctioned",
        "psa_owned_by_ofac_sdn_mex_dto_sanctioned",
        "psa_owned_by_ofac_sdnt_sanctioned",
        "psa_owned_by_ofac_sdntk_sanctioned",
        "psa_owned_by_sanctioned_arg_repet_jus_entity",
        "psa_owned_by_sanctioned_aus_dfat_entity",
        "psa_owned_by_sanctioned_bel_fpsf_entity",
        "psa_owned_by_sanctioned_can_gac_entity",
        "psa_owned_by_sanctioned_che_seco_entity",
        "psa_owned_by_sanctioned_cze_mof_entity",
        "psa_owned_by_sanctioned_entity",
        "psa_owned_by_sanctioned_eu_dg_fisma_ec_entity",
        "psa_owned_by_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_owned_by_sanctioned_eu_ec_sanctions_map_entity",
        "psa_owned_by_sanctioned_eu_sanctions_entity",
        "psa_owned_by_sanctioned_fra_dgt_mefids_entity",
        "psa_owned_by_sanctioned_gbr_fcdo_entity",
        "psa_owned_by_sanctioned_gbr_hmt_ofsi_entity",
        "psa_owned_by_sanctioned_isr_mod_nbctf_entity",
        "psa_owned_by_sanctioned_jpn_mof_entity",
        "psa_owned_by_sanctioned_ltu_mi_entity",
        "psa_owned_by_sanctioned_lva_fis_entity",
        "psa_owned_by_sanctioned_mys_moha_entity",
        "psa_owned_by_sanctioned_nld_mofa_entity",
        "psa_owned_by_sanctioned_nzl_mfat_rus_entity",
        "psa_owned_by_sanctioned_pol_mia_entity",
        "psa_owned_by_sanctioned_sgp_agc_entity",
        "psa_owned_by_sanctioned_ukr_nsdc_entity",
        "psa_owned_by_sanctioned_ukr_sfms_entity",
        "psa_owned_by_sanctioned_un_sc_entity",
        "psa_owned_by_sanctioned_usa_ofac_non_sdn_entity",
        "psa_owned_by_sanctioned_usa_ofac_sdn_entity",
        "psa_owned_by_sanctioned_xxx_ebrd_entity",
        "psa_owned_by_sanctioned_xxx_iabd_entity",
        "psa_owned_by_section_1260h_entity",
        "psa_owned_by_sheffield_hallam_university_reports_forced_labor_entity",
        "psa_owned_by_soe",
        "psa_owned_by_usa_aeca_debarred_entity",
        "psa_owned_by_usa_bis_denied_persons_entity",
        "psa_owned_by_usa_bis_entity",
        "psa_owned_by_usa_bis_meu_entity",
        "psa_owned_by_usa_bis_unverified_entity",
        "psa_owned_by_usa_isn_entity",
        "psa_owned_by_usa_section_1260h_entity",
        "psa_owned_by_wro_entity",
        "psa_owned_by_xinjiang_entity",
        "psa_owner_of_aspi_forced_labor_entity",
        "psa_owner_of_chinese_soe",
        "psa_owner_of_export_controls_entity",
        "psa_owner_of_forced_labor_xinjiang_entity",
        "psa_owner_of_forced_labor_xinjiang_uflpa",
        "psa_owner_of_jpn_meti_end_user_entity",
        "psa_owner_of_jpn_mofa_export_ban_entity",
        "psa_owner_of_ofac_fto_sanctioned",
        "psa_owner_of_ofac_illicit_drugs_eo14059_sanctioned",
        "psa_owner_of_ofac_sdgt_sanctioned",
        "psa_owner_of_ofac_sdn_mex_dto_sanctioned",
        "psa_owner_of_ofac_sdnt_sanctioned",
        "psa_owner_of_ofac_sdntk_sanctioned",
        "psa_owner_of_regulatory_action_entity",
        "psa_owner_of_sanctioned_arg_repet_jus_entity",
        "psa_owner_of_sanctioned_aus_dfat_entity",
        "psa_owner_of_sanctioned_bel_fpsf_entity",
        "psa_owner_of_sanctioned_can_gac_entity",
        "psa_owner_of_sanctioned_che_seco_entity",
        "psa_owner_of_sanctioned_cze_mof_entity",
        "psa_owner_of_sanctioned_entity",
        "psa_owner_of_sanctioned_eu_dg_fisma_ec_entity",
        "psa_owner_of_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_owner_of_sanctioned_eu_ec_sanctions_map_entity",
        "psa_owner_of_sanctioned_eu_sanctions_entity",
        "psa_owner_of_sanctioned_fra_dgt_mefids_entity",
        "psa_owner_of_sanctioned_gbr_fcdo_entity",
        "psa_owner_of_sanctioned_gbr_hmt_ofsi_entity",
        "psa_owner_of_sanctioned_isr_mod_nbctf_entity",
        "psa_owner_of_sanctioned_jpn_mof_entity",
        "psa_owner_of_sanctioned_ltu_mi_entity",
        "psa_owner_of_sanctioned_lva_fis_entity",
        "psa_owner_of_sanctioned_mys_moha_entity",
        "psa_owner_of_sanctioned_nld_mofa_entity",
        "psa_owner_of_sanctioned_nzl_mfat_rus_entity",
        "psa_owner_of_sanctioned_pol_mia_entity",
        "psa_owner_of_sanctioned_sgp_agc_entity",
        "psa_owner_of_sanctioned_ukr_nsdc_entity",
        "psa_owner_of_sanctioned_ukr_sfms_entity",
        "psa_owner_of_sanctioned_un_sc_entity",
        "psa_owner_of_sanctioned_usa_ofac_non_sdn_entity",
        "psa_owner_of_sanctioned_usa_ofac_sdn_entity",
        "psa_owner_of_sanctioned_xxx_ebrd_entity",
        "psa_owner_of_sanctioned_xxx_iabd_entity",
        "psa_owner_of_sheffield_hallam_university_reports_forced_labor_entity",
        "psa_owner_of_soe",
        "psa_owner_of_usa_aeca_debarred_entity",
        "psa_owner_of_usa_bis_denied_persons_entity",
        "psa_owner_of_usa_bis_entity",
        "psa_owner_of_usa_bis_meu_entity",
        "psa_owner_of_usa_bis_unverified_entity",
        "psa_owner_of_usa_isn_entity",
        "psa_owner_of_usa_section_1260h_entity",
        "psa_owner_of_wro_entity",
        "psa_pep",
        "psa_regulatory_action",
        "psa_sanctioned",
        "psa_sanctioned_arg_repet_jus",
        "psa_sanctioned_aus_dfat",
        "psa_sanctioned_bel_fpsf",
        "psa_sanctioned_can_gac",
        "psa_sanctioned_che_seco",
        "psa_sanctioned_cze_mof",
        "psa_sanctioned_eu_dg_fisma_ec",
        "psa_sanctioned_eu_ec_regulation_833_2014",
        "psa_sanctioned_eu_ec_sanctions_map",
        "psa_sanctioned_eu_sanctions",
        "psa_sanctioned_fra_dgt_mefids",
        "psa_sanctioned_gbr_fcdo",
        "psa_sanctioned_gbr_hmt_ofsi",
        "psa_sanctioned_isr_mod_nbctf",
        "psa_sanctioned_jpn_mof",
        "psa_sanctioned_ltu_mi",
        "psa_sanctioned_lva_fis",
        "psa_sanctioned_mys_moha",
        "psa_sanctioned_nld_mofa",
        "psa_sanctioned_nzl_mfat_rus",
        "psa_sanctioned_pol_mia",
        "psa_sanctioned_sgp_agc",
        "psa_sanctioned_ukr_nsdc",
        "psa_sanctioned_ukr_sfms",
        "psa_sanctioned_un_sc",
        "psa_sanctioned_usa_ofac_non_sdn",
        "psa_sanctioned_usa_ofac_sdn",
        "psa_sanctioned_xxx_ebrd",
        "psa_sanctioned_xxx_iabd",
        "psa_sheffield_hallam_university_forced_labor_entity",
        "psa_sheffield_hallam_university_intermediary_entity",
        "psa_sheffield_hallam_university_useful_resources",
        "psa_state_owned",
        "psa_state_owned_ven",
        "psa_uk_50_percent_rule",
        "psa_uk_minority_ownership",
        "psa_usa_aeca_debarred",
        "psa_usa_bis",
        "psa_usa_bis_50_percent_rule",
        "psa_usa_bis_denied_persons",
        "psa_usa_bis_meu",
        "psa_usa_bis_meu_50_percent_rule",
        "psa_usa_bis_unverified",
        "psa_usa_isn",
        "psa_usa_section_1260h",
        "psa_ven_soe_50_percent",
        "psa_wro_entity",
        "regulatory_action",
        "reputational_risk_bribery_and_corruption",
        "reputational_risk_cybercrime",
        "reputational_risk_financial_crime",
        "reputational_risk_forced_labor",
        "reputational_risk_organized_crime",
        "reputational_risk_other",
        "reputational_risk_terrorism",
        "sanctioned",
        "sanctioned_adjacent",
        "sanctioned_arg_repet_jus",
        "sanctioned_aus_dfat",
        "sanctioned_bel_fpsf",
        "sanctioned_can_gac",
        "sanctioned_che_seco",
        "sanctioned_cze_mof",
        "sanctioned_eu_dg_fisma_ec",
        "sanctioned_eu_ec_regulation_269_2014",
        "sanctioned_eu_ec_regulation_833_2014",
        "sanctioned_eu_ec_sanctions_map",
        "sanctioned_eu_sanctions",
        "sanctioned_fra_dgt_mefids",
        "sanctioned_gbr_fcdo",
        "sanctioned_gbr_hmt_ofsi",
        "sanctioned_isr_mod_nbctf",
        "sanctioned_jpn_mof",
        "sanctioned_ltu_mi",
        "sanctioned_lva_fis",
        "sanctioned_mys_moha",
        "sanctioned_nld_mofa",
        "sanctioned_nzl_mfat_rus",
        "sanctioned_pol_mia",
        "sanctioned_sgp_agc",
        "sanctioned_ukr_nsdc",
        "sanctioned_ukr_sfms",
        "sanctioned_un_sc",
        "sanctioned_usa_ofac_non_sdn",
        "sanctioned_usa_ofac_sdn",
        "sanctioned_xxx_ebrd",
        "sanctioned_xxx_iabd",
        "sheffield_hallam_university_forced_labor_entity",
        "sheffield_hallam_university_forced_labor_reports_entity_adjacent",
        "sheffield_hallam_university_forced_labor_reports_intermediary_entity",
        "sheffield_hallam_university_useful_resources",
        "soe_adjacent",
        "state_owned",
        "state_owned_ven",
        "subsidiary_of_ndaa_889_covered_entities",
        "uk_50_percent_rule",
        "uk_minority_ownership",
        "uk_sanctioned",
        "usa_aeca_debarred",
        "usa_bis",
        "usa_bis_50_percent_rule",
        "usa_bis_denied_persons",
        "usa_bis_meu",
        "usa_bis_meu_50_percent_rule",
        "usa_bis_unverified",
        "usa_isn",
        "usa_section_1260h",
        "ven_soe_50_percent",
        "wro_entity",
        "wro_entity_adjacent",
    ],
    typing.Any,
]
