# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .share_information import ShareInformation
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntityRiskSummaryNetworkPath(UniversalBaseModel):
    sayari_entity_id: str
    sayari_entity_label: str
    relationship_type: str
    relationship_status: str
    former: bool
    first_observed: str
    last_observed: str
    start_date: typing.Optional[str] = None
    shares: typing.Optional[ShareInformation] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
