# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.entities import Entities
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class OntologyEntityTypesFilters(UniversalBaseModel):
    id: typing.Optional[typing.List[Entities]] = pydantic.Field(default=None)
    """
    Entity type Id filter.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
