# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .create_project_entity_attribute_response_data import CreateProjectEntityAttributeResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class CreateProjectEntityAttributeResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_attributes import (
        CreateProjectEntityAttributeResponse,
        CreateProjectEntityAttributeResponseData,
    )

    CreateProjectEntityAttributeResponse(
        data=CreateProjectEntityAttributeResponseData(
            id="nK9mP2",
            field="custom_phone",
            value="+1-555-123-4567",
            match_resolution=False,
        ),
    )
    """

    data: CreateProjectEntityAttributeResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
