# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .trade_traversal_path import TradeTraversalPath
from .trade_traversal_entity import TradeTraversalEntity
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TradeTraversalData(UniversalBaseModel):
    paths: typing.List[TradeTraversalPath]
    entities: typing.Dict[str, TradeTraversalEntity]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
