# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .trade_traversal_component import TradeTraversalComponent
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TradeTraversalPathSegment(UniversalBaseModel):
    tier: int = pydantic.Field()
    """
    Associated tier for that path segment (1-5)
    """

    entity_id: str = pydantic.Field()
    """
    Supplier entity ID
    """

    components: typing.List[TradeTraversalComponent] = pydantic.Field()
    """
    Components shipped by the supplier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
