# This file was auto-generated by Fern from our API Definition.

import typing

ReportingPeriodType = typing.Union[
    typing.Literal[
        "annual_fiscal", "last_twelve_months", "quarterly_fiscal", "semi_annual_fiscal", "year_to_date_fiscal"
    ],
    typing.Any,
]
