# This file was auto-generated by Fern from our API Definition.

import typing

Topics = typing.Union[
    typing.Literal[
        "overview",
        "environmental_and_social",
        "cybersecurity",
        "disruption",
        "criminal",
        "reputational",
        "financial",
        "sanctions_and_regulatory",
        "legal",
        "political",
        "terrorism",
    ],
    typing.Any,
]
