# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class UpdateProjectEntityAttributeRequest(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_attributes import UpdateProjectEntityAttributeRequest

    UpdateProjectEntityAttributeRequest(
        field="name",
        value="updated name",
        match_resolution=True,
    )
    """

    field: str
    value: str
    match_resolution: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
