# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .update_project_entity_attribute_response_data import UpdateProjectEntityAttributeResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class UpdateProjectEntityAttributeResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_attributes import (
        UpdateProjectEntityAttributeResponse,
        UpdateProjectEntityAttributeResponseData,
    )

    UpdateProjectEntityAttributeResponse(
        data=UpdateProjectEntityAttributeResponseData(
            id="xG8wYP",
            field="name",
            value="updated name",
            match_resolution=True,
        ),
    )
    """

    data: UpdateProjectEntityAttributeResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
