# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .field_match_quality import FieldMatchQuality
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectEntityMatchExplanation(UniversalBaseModel):
    field: str
    quality: FieldMatchQuality = pydantic.Field()
    """
    Quality of the match
    """

    description: typing.Optional[typing.List[str]] = None
    matches: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
