# This file was auto-generated by Fern from our API Definition.

from .resolution_response_fields import ResolutionResponseFields
import typing_extensions
import typing
from ...base_types.types.custom_field_value import CustomFieldValue
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionPersistedResponseFields(ResolutionResponseFields):
    custom_field_name: typing_extensions.Annotated[
        typing.Optional[CustomFieldValue], FieldMetadata(alias="custom_{field name}")
    ] = None
    custom_name: typing.Optional[str] = None
    custom_identifier: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
