# This file was auto-generated by Fern from our API Definition.

import typing
from ...generated_types.types.risk_category import RiskCategory

TraversalRiskCategory = typing.Union[typing.List[RiskCategory], str]
