# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_entity_supply_chain_snapshot_data import ProjectEntitySupplyChainSnapshotData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainSnapshotsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_supply_chain_snapshots import (
        ProjectEntitySupplyChainSnapshotData,
        ProjectEntitySupplyChainSnapshotsResponse,
    )

    ProjectEntitySupplyChainSnapshotsResponse(
        data=[
            ProjectEntitySupplyChainSnapshotData(
                snapshot_id="xG8wYP",
                label="My REST Snapshot",
                release_tag="20220429212557_test",
                partial_results=False,
                explored_count=6,
                created_at="2025-08-12 20:13:20.49643+00",
                updated_at="2025-08-12 20:13:20.49643+00",
            )
        ],
    )
    """

    data: typing.List[ProjectEntitySupplyChainSnapshotData]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
