# This file was auto-generated by Fern from our API Definition.

import typing

RiskCategory = typing.Union[
    typing.Literal[
        "adverse_media",
        "environmental_risk",
        "export_controls",
        "forced_labor",
        "political_exposure",
        "regulatory_action",
        "sanctions",
        "sanctions_and_export_control_lists",
    ],
    typing.Any,
]
