# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .supply_chain_node import SupplyChainNode
from .supply_chain_edge import SupplyChainEdge
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainSnapshotDetailData(UniversalBaseModel):
    snapshot_id: str
    label: str
    release_tag: str
    partial_results: bool
    explored_count: int
    created_at: str
    updated_at: str
    nodes: typing.List[SupplyChainNode]
    edges: typing.List[SupplyChainEdge]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
