# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_identifiers_filters import OntologyIdentifiersFilters
import typing
from .ontology_identifier import OntologyIdentifier
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyIdentifiersResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyIdentifiersResponse,
        OntologyIdentifier,
        OntologyIdentifiersFilters,
    )

    GetOntologyIdentifiersResponse(
        filters=OntologyIdentifiersFilters(
            id=["aer_free_zone_license"],
        ),
        data=[
            OntologyIdentifier(
                id="aer_free_zone_license",
                label="UAE DAFZ Primary License Number",
                comment="Primary license number of free zone establishment in Dubai",
                regex="^\\d+$",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyIdentifiersFilters
    data: typing.List[OntologyIdentifier]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
