# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .risk_change_factor_change_type import RiskChangeFactorChangeType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class RiskChangeFactor(UniversalBaseModel):
    id: str
    timestamp: str = pydantic.Field()
    """
    Timestamp of risk change detection
    """

    change_type: RiskChangeFactorChangeType

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
