# This file was auto-generated by Fern from our API Definition.

import typing

CountType = typing.Union[typing.Literal["coordinates", "upstream_product_risk", "upstream_product_country"], typing.Any]
