# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.unprocessable_content_response import UnprocessableContentResponse


class UnprocessableContent(ApiError):
    def __init__(self, body: UnprocessableContentResponse):
        super().__init__(status_code=422, body=body)
