# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectNotificationRiskData(UniversalBaseModel):
    added: typing.List[str] = pydantic.Field()
    """
    The list of fields added
    """

    removed: typing.List[str] = pydantic.Field()
    """
    The list of fields removed
    """

    date: str = pydantic.Field()
    """
    The date of the notification
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
