# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_languages_filters import OntologyLanguagesFilters
import typing
from .ontology_language import OntologyLanguage
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyLanguagesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyLanguagesResponse,
        OntologyLanguage,
        OntologyLanguagesFilters,
    )

    GetOntologyLanguagesResponse(
        filters=OntologyLanguagesFilters(
            id=["en"],
        ),
        data=[
            OntologyLanguage(
                id="en",
                label="English",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyLanguagesFilters
    data: typing.List[OntologyLanguage]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
