# This file was auto-generated by Fern from our API Definition.

import enum


class SayariEnvironment(enum.Enum):
    PRODUCTION = "https://api.sayari.com"
    """
    Sayari production - the default environment
    """

    DEV = "https://api.internal.sayari.com"
    """
    Sayari development - utilized for internal testing before promotion to production
    """

    PRODUCTION_UK = "https://api.uk.sayari.com"
    """
    Sayari production - UK environment
    """
