# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.country import Country
from .risk_categories_summary import RiskCategoriesSummary
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntitySupplyChainUpstream(UniversalBaseModel):
    components: typing.List[str]
    countries: typing.List[Country]
    risk_categories: typing.List[RiskCategoriesSummary]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
